//
// MessagePack for C++ static resolution routine
//
// Copyright (C) 2008-2014 FURUHASHI Sadayuki and KONDO Takatoshi
//
//    Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE_1_0.txt or copy at
//    http://www.boost.org/LICENSE_1_0.txt)
//
#ifndef MSGPACK_MSGPACK_TUPLE_HPP
#define MSGPACK_MSGPACK_TUPLE_HPP

#include "msgpack/adaptor/msgpack_tuple_decl.hpp"

#include "msgpack/v1/adaptor/msgpack_tuple.hpp"

#endif // MSGPACK_MSGPACK_TUPLE_HPP
