//
// MessagePack for C++ memory pool
//
// Copyright (C) 2016 KONDO Takatoshi
//
//    Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE_1_0.txt or copy at
//    http://www.boost.org/LICENSE_1_0.txt)
//
#ifndef MSGPACK_ZONE_DECL_HPP
#define MSGPACK_ZONE_DECL_HPP

#include "msgpack/v1/zone_decl.hpp"
#include "msgpack/v2/zone_decl.hpp"

#endif // MSGPACK_ZONE_DECL_HPP
